@@ -1,3 +1,3 @@
-from .redis_queue import RedisQueue, RedisClusterQueue
+from .redis_queue import RedisQueue
 from .mongo_queue import MongoQueue
 from .task import BaseTask
