@@ -1,3 +1,5 @@
+from .task import BaseTask
+
 
 class AbstractQueue:
 
@@ -7,6 +9,13 @@ class AbstractQueue:
         self.cfg = qcfg
 
     def enqueue(self, task):
+        if not isinstance(task, BaseTask):
+            raise TypeError("only instances of Task are allowed")
+        if task.received:
+            raise RuntimeError("task is already received by a subscriber")
+        self._enqueue(task)
+
+    def _enqueue(self, task):
         raise NotImplementedError("abstract queue")
 
     def ack(self, task_id):
