@@ -16,6 +16,7 @@ class MongoQueue(AbstractQueue):
 
     def __init__(self, qcfq):
         super(MongoQueue, self).__init__(qcfq)
+        self._initialized = False
         self.task_collection = self.cfg.get("collection", "mq_tasks")
         self.subs_collection = self.task_collection + "_subs"
         self.prefix = self.cfg.get("channel", "ueq")
@@ -29,13 +30,16 @@ class MongoQueue(AbstractQueue):
         self.msgchannel = f"{self.prefix}:{fqdn}:{rand}"
         self.ackchannel = f"{self.prefix}:{fqdn}:{rand}:ack"
 
+    def initialize(self):
         self.ensure_indexes()
         self.cleanup_channels()
+        self._initialized = True
 
     def ensure_indexes(self):
         self.coll_subs.ensure_index("updated_at")
         self.coll_subs.ensure_index("chan")
-        self.coll_tasks.ensure_index([("chan", ASCENDING), ("created_at", ASCENDING)])
+        self.coll_tasks.ensure_index(
+            [("chan", ASCENDING), ("created_at", ASCENDING)])
 
     def cleanup_channels(self):
         min_date = now() - self.channel_ttl
@@ -77,19 +81,20 @@ class MongoQueue(AbstractQueue):
     def ack(self, task_id):
         # generate ack
         ctx.log.debug("ACK {ins_id: %s, chan: %s}", task_id, self.ackchannel)
-        self.coll_tasks.insert_one({"ins_id": task_id, "chan": self.ackchannel})
+        self.coll_tasks.insert_one(
+            {"ins_id": task_id, "chan": self.ackchannel})
         # remove task doc
         ctx.log.debug("DELETE {_id: %s}", task_id)
         self.coll_tasks.delete_one({"_id": task_id})
 
     def publish(self, chan, data):
-        res = self.coll_tasks.insert_one({"chan": chan, "data": data, "created_at": now()})
+        res = self.coll_tasks.insert_one(
+            {"chan": chan, "data": data, "created_at": now()})
         return res.inserted_id
 
-    def enqueue(self, task):
-        if not isinstance(task, BaseTask):
-            raise TypeError("only instances of Task are allowed")
-
+    def _enqueue(self, task):
+        if not self._initialized:
+            self.initialize()
         ack = None
         retries = self.retries
         while retries > 0:
@@ -111,10 +116,13 @@ class MongoQueue(AbstractQueue):
 
     @property
     def tasks(self):
+        if not self._initialized:
+            self.initialize()
         self.subscribe()
         resub_at = now() + timedelta(seconds=10)
         while True:
-            msgs = self.coll_tasks.find({"chan": self.msgchannel}).sort("created_at", ASCENDING)
+            msgs = self.coll_tasks.find(
+                {"chan": self.msgchannel}).sort("created_at", ASCENDING)
             if msgs.count() > 0:
                 for msg in msgs:
                     task = BaseTask.from_message(msg)
